.. _automatic-name:

!!!!!!!!!
automatic
!!!!!!!!!

.. meta::
   :keywords: automatic,processing

.. index:: automatic, automatic, processing

.. _automatic-title:

Automatic Processing
####################
The processing described below happens without any commands:

-  :ref:`heading_links-title`
-  :ref:`auto_file-title`

.. toctree::
   :maxdepth: 1
   :hidden:

   heading_links
   auto_file
